==> skrooge_0.2.9.orig.tar.gz: skrooge-0.2.9/skrooge_undoredo/skgundoredoplugin.h <==
/***************************************************************************
 *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@miraks.com    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>  *
 ***************************************************************************/
#ifndef SKGUNDOREDOPLUGIN_H
#define SKGUNDOREDOPLUGIN_H
/** @file
 * This file is Skrooge plugin for undo and redo operation.
*
* @author Stephane MANKOWSKI / Guillaume DE BURE
 */
#include "skginterfaceplugin.h"
#include "ui_skgundoredopluginwidget_pref.h"
#include <QObject>
#include <QVariantList>
#include <kgenericfactory.h>

class KAction;
class KToolBarPopupAction;
class KMenu;
class SKGDocumentBank;
class SKGMainPanel;

/**
 * This file is Skrooge plugin for undo and redo operation
 */
class SKGUndoRedoPlugin : public SKGInterfacePlugin
{
        Q_OBJECT
        Q_INTERFACES(SKGInterfacePlugin);

public:
        /**
         * Default Constructor
         */
        SKGUndoRedoPlugin(QObject* iParent, const QVariantList& iArg);

        /**
         * Default Destructor
         */
        virtual ~SKGUndoRedoPlugin();

        /**
         * Called to initialise the plugin
         * @param iParent the SKGMainPanel main panel parent
         * @param iDocument the SKGDocumentBank main document
         * @param iArgument the arguments
         */
        virtual void setupActions(SKGMainPanel* iParent, SKGDocument* iDocument, const QStringList& iArgument);

        /**
         * Must be modified to close properly the plugin.
         */
        virtual void close();

        /**
         * Must be modified to refresh widgets after a modification.
         */
        virtual void refresh();

        /**
         * The preference widget of the plugin.
         * @return The preference widget of the plugin
         */
        virtual QWidget* getPreferenceWidget();

        /**
         * The preference skeleton of the plugin.
         * @return The preference skeleton of the plugin
         */
        virtual KConfigSkeleton* getPreferenceSkeleton();

        /**
         * This function is called when preferences have been modified. Must be used to save some parameters into the document.
         * A transaction is already opened
         * @return an object managing the error.
         *   @see SKGError
         */
        virtual SKGError savePreferences() const;

        /**
         * The title of the plugin.
         * @return The title of the plugin
         */
        virtual QString title() const;

        /**
         * The icon of the plugin.
         * @return The icon of the plugin
         */
        virtual QString icon() const;

        /**
         * The statusTip of the plugin.
         * @return The toolTip of the plugin
         */
        virtual QString statusTip () const;

        /**
         * The toolTip of the plugin.
         * @return The toolTip of the plugin
         */
        virtual QString toolTip () const;

        /**
         * The tips list of the plugin.
         * @return The tips list of the plugin
         */
        virtual QStringList tips() const;

        /**
         * Must be implemented to set the position of the plugin.
         * @return integer value between 0 and 999 (default = 999)
         */
        virtual int getOrder() const;

        /**
         * The dock widget of the plugin.
         * @return The dock widget of the plugin
         */
        virtual QDockWidget* getDockWidget();

private slots:
        void actionUndoSave();
        void actionUndo();
        void actionRedo();

        void onShowUndoMenu();
        void onShowRedoMenu();
private:
        Q_DISABLE_COPY(SKGUndoRedoPlugin);

        KAction *undoSaveAction;
        KToolBarPopupAction *undoAction;
        KToolBarPopupAction *redoAction;

        KMenu *undoMenu;
        KMenu *redoMenu;

        SKGMainPanel *parent;
        SKGDocument* currentBankDocument;
        QDockWidget* dockWidget;

        Ui::skgundoredoplugin_pref ui;
};

#endif // SKGDEBUGPLUGIN_H

==> skrooge-0.5.2.tar.gz: skrooge-0.5.2/skrooge_undoredo/skgundoredoplugin.h <==
/***************************************************************************
 *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@miraks.com    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>  *
 ***************************************************************************/
#ifndef SKGUNDOREDOPLUGIN_H
#define SKGUNDOREDOPLUGIN_H
/** @file
 * This file is Skrooge plugin for undo and redo operation.
*
* @author Stephane MANKOWSKI / Guillaume DE BURE
 */
#include "skginterfaceplugin.h"
#include "ui_skgundoredopluginwidget_pref.h"
#include <QObject>
#include <QVariantList>
#include <kgenericfactory.h>

class KAction;
class KToolBarPopupAction;
class KMenu;
class SKGDocumentBank;
class SKGMainPanel;

/**
 * This file is Skrooge plugin for undo and redo operation
 */
class SKGUndoRedoPlugin : public SKGInterfacePlugin
{
        Q_OBJECT
        Q_INTERFACES(SKGInterfacePlugin);

public:
        /**
         * Default Constructor
         */
        SKGUndoRedoPlugin(QObject* iParent, const QVariantList& iArg);

        /**
         * Default Destructor
         */
        virtual ~SKGUndoRedoPlugin();

        /**
         * Called to initialise the plugin
         * @param iDocument the SKGDocumentBank main document
         * @param iArgument the arguments
         */
        virtual void setupActions(SKGDocument* iDocument, const QStringList& iArgument);

        /**
         * Must be modified to close properly the plugin.
         */
        virtual void close();

        /**
         * Must be modified to refresh widgets after a modification.
         */
        virtual void refresh();

        /**
         * The preference widget of the plugin.
         * @return The preference widget of the plugin
         */
        virtual QWidget* getPreferenceWidget();

        /**
         * The preference skeleton of the plugin.
         * @return The preference skeleton of the plugin
         */
        virtual KConfigSkeleton* getPreferenceSkeleton();

        /**
         * This function is called when preferences have been modified. Must be used to save some parameters into the document.
         * A transaction is already opened
         * @return an object managing the error.
         *   @see SKGError
         */
        virtual SKGError savePreferences() const;

        /**
         * The title of the plugin.
         * @return The title of the plugin
         */
        virtual QString title() const;

        /**
         * The icon of the plugin.
         * @return The icon of the plugin
         */
        virtual QString icon() const;

        /**
         * The statusTip of the plugin.
         * @return The toolTip of the plugin
         */
        virtual QString statusTip () const;

        /**
         * The toolTip of the plugin.
         * @return The toolTip of the plugin
         */
        virtual QString toolTip () const;

        /**
         * The tips list of the plugin.
         * @return The tips list of the plugin
         */
        virtual QStringList tips() const;

        /**
         * Must be implemented to set the position of the plugin.
         * @return integer value between 0 and 999 (default = 999)
         */
        virtual int getOrder() const;

        /**
         * The dock widget of the plugin.
         * @return The dock widget of the plugin
         */
        virtual QDockWidget* getDockWidget();

private slots:
        void actionUndoSave();
        void actionUndo();
        void actionRedo();

        void onShowUndoMenu();
        void onShowRedoMenu();
private:
        Q_DISABLE_COPY(SKGUndoRedoPlugin);

        KAction *undoSaveAction;
        KToolBarPopupAction *undoAction;
        KToolBarPopupAction *redoAction;

        KMenu *undoMenu;
        KMenu *redoMenu;


        SKGDocument* currentBankDocument;
        QDockWidget* dockWidget;

        Ui::skgundoredoplugin_pref ui;
};

#endif // SKGDEBUGPLUGIN_H
